@@ -38,6 +38,7 @@
 #include "common/nmv-address.h"
 #include "common/nmv-asm-instr.h"
 #include "common/nmv-loc.h"
+#include "common/nmv-str-utils.h"
 #include "nmv-i-conf-mgr.h"
 
 using nemiver::common::SafePtr;
@@ -115,6 +116,21 @@ public:
         int m_ignore_count;
         bool m_is_read_watchpoint;
         bool m_is_write_watchpoint;
+        // The list of sub-breakpoints, in case this breakpoint is a
+        // multiple breakpoint.  In that case, each sub-breakpoint
+        // will be set to a real location of an overload function.
+        // Each sub-breakpoint will then have a non-nil
+        // m_parent_breakpoint pointer that points back to this
+        // instance, and an empty m_sub_breakpoints member.
+        vector<Breakpoint> m_sub_breakpoints;
+        // If this instance is a sub-breakpoint, i.e, a breakpoint to
+        // an overloaded function that has been set by name to all the
+        // overloads at the same time, then this is set to the id of
+        // the parent breakpoint.  The parent breakpoint contains
+        // information that are relevant for all the sub-breakpoints.
+        int m_parent_breakpoint_number;
+        // Whether the breakpoint is pending.
+        bool m_is_pending;
 
     public:
         Breakpoint () {clear ();}
@@ -122,15 +138,70 @@ public:
         /// \name accessors
 
         /// @{
-        int number () const {return m_number;}
+
+        /// Getter of the ID of this breakpoint.  If the breakpoint is
+        /// a sub breakpoint, its id has the form of the string "5.4"
+        /// where 5 is the number of the parent breakpoint and 4 is
+        /// the number of this sub breakpoint.
+        ///
+        /// @return the ID this breakpoint.
+        string id () const
+        {
+            if (is_sub_breakpoint ())
+                return (str_utils::int_to_string (parent_breakpoint_number ()) + "."
+                        + str_utils::int_to_string (sub_breakpoint_number ()));
+            else
+                return str_utils::int_to_string (sub_breakpoint_number ());
+        }
+
+        /// Getter of the ID of the parent of this breakpoint.
+        ///
+        ///Note that (at least for GDB) only parent breakpoints can be
+        ///deleted by ID
+        ///
+        ///@return the ID of the parent of this breakpoint.
+        string parent_id () const
+        {
+            string id;
+            if (is_sub_breakpoint ())
+                id = str_utils::int_to_string(parent_breakpoint_number ());
+            else
+                id = str_utils::int_to_string (sub_breakpoint_number ());
+            return id;
+        }
+
+        /// Getter of the ID of this breakpoint.  If the breakpoint is
+        /// a sub breakpoint, its id has the form of the string "5.4"
+        /// where 5 is the number of the parent breakpoint and 4 is
+        /// the number of this sub breakpoint.
+        ///
+        /// @param s out parameter. Set to the ID of this breakpoint.
+        void id (string& s) const
+        {
+            s = number ();
+        }
+
+        /// Getter of the number of this breakpoint.  Note that if
+        /// this is a sub breakpoint, what you might want is the
+        /// number of the parent breakpoint.
+        ///
+        /// @return the integer number of this breakpoint.
+        int number() const {return sub_breakpoint_number();}
+
         void number (int a_in) {m_number = a_in;}
+        int sub_breakpoint_number () const {return m_number;}
 
         bool enabled () const {return m_enabled;}
         void enabled (bool a_in) {m_enabled = a_in;}
 
         const Address& address () const {return m_address;}
         Address& address () {return m_address;}
-        void address (const string &a_in) {m_address = a_in;}
+        void address (const string &a_in)
+        {
+            m_address = a_in;
+            if (!m_address.empty ())
+                m_is_pending = false;
+        }
 
         const string& function () const {return m_function;}
         void function (const string &a_in) {m_function = a_in;}
@@ -172,14 +243,32 @@ public:
         bool is_write_watchpoint () const {return m_is_write_watchpoint;}
         void is_write_watchpoint (bool f) {m_is_write_watchpoint = f;}
 
-        bool is_pending () const
+        bool is_pending () const {return m_is_pending;}
+        void is_pending (bool a) {m_is_pending = a;}
+
+        /// Test whether this breakpoint has multiple location.
+        ///
+        /// Each location is then represented by a sub-breakpoint,
+        /// that is a child breakpoint of this instance of
+        /// breakpoint.  The sub-breakpoints can be retrieved by the
+        /// #sub_breakpoints below.
+        bool has_multiple_locations () const {return !m_sub_breakpoints.empty ();}
+
+        void append_sub_breakpoint (Breakpoint& b)
         {
-            if (m_address == "<PENDING>") {
-                return true;
-            }
-            return false;
+            b.m_parent_breakpoint_number = m_number;
+            m_sub_breakpoints.push_back (b);
         }
 
+        const vector<Breakpoint>& sub_breakpoints () const
+        {
+            return m_sub_breakpoints;
+        }
+
+        int parent_breakpoint_number () const {return m_parent_breakpoint_number;}
+
+        bool is_sub_breakpoint () const {return !!parent_breakpoint_number ();}
+
         Type type () const {return m_type;}
         void type (Type a_type) {m_type = a_type;}
 
@@ -202,6 +291,9 @@ public:
             m_ignore_count = 0;
             m_is_read_watchpoint = false;
             m_is_write_watchpoint = false;
+            m_sub_breakpoints.clear ();
+            m_parent_breakpoint_number = 0;
+            m_is_pending = false;
         }
     };//end class Breakpoint
 
@@ -270,6 +362,7 @@ public:
         int line_number () const {return m_line_number;}
         void line_number (int a_in) {m_line_number = a_in;}
     };//end class OverloadsChoiceEntry
+    typedef vector<OverloadsChoiceEntry> OverloadsChoiceEntries;
 
     class Variable;
     typedef SafePtr<Variable, ObjectRef, ObjectUnref> VariableSafePtr;
@@ -996,15 +1089,11 @@ public:
     }
 
     typedef sigc::slot<void,
-                       const std::pair<int, const IDebugger::Breakpoint&>&>
-        BreakpointSlot;
-
-    typedef sigc::slot<void,
-                       const std::map<int, IDebugger::Breakpoint>&>
+                       const std::map<string, IDebugger::Breakpoint>&>
         BreakpointsSlot;
 
     typedef sigc::slot<void, Loc&> LocSlot;
-    
+
     virtual ~IDebugger () {}
 
     /// \name events you can connect to.
@@ -1038,7 +1127,7 @@ public:
 
     virtual sigc::signal<void,
                         const IDebugger::Breakpoint&,
-                        int /*breakpoint command*/,
+                        const string& /*breakpoint number*/,
                         const UString & /*cookie*/>&
                                      breakpoint_deleted_signal () const=0;
 
@@ -1048,12 +1137,12 @@ public:
     /// IDebugger does not cache the list of breakpoints. This must
     /// be fixed at some point.
     virtual sigc::signal<void,
-                         const map<int, IDebugger::Breakpoint>&,
+                         const map<string, IDebugger::Breakpoint>&,
                          const UString& /*cookie*/>&
                                          breakpoints_list_signal () const=0;
 
     virtual sigc::signal<void,
-                        const std::map<int, IDebugger::Breakpoint>&,
+                        const std::map<string, IDebugger::Breakpoint>&,
                         const UString& /*cookie*/>&
                         breakpoints_set_signal () const = 0;
 
@@ -1067,9 +1156,9 @@ public:
                          bool /*has frame*/,
                          const IDebugger::Frame&/*the frame*/,
                          int /*thread id*/,
-                         int /*breakpoint number,
-                               meaningfull only when
-                               reason == IDebugger::BREAKPOINT_HIT*/,
+                         const string& /*breakpoint number,
+                                         meaningfull only when
+                                         reason == IDebugger::BREAKPOINT_HIT*/,
                          const UString& /*cookie*/>& stopped_signal () const=0;
 
     virtual sigc::signal<void,
@@ -1359,35 +1448,41 @@ public:
                                  gint a_ignore_count = 0,
                                  const UString &a_cookie = "") = 0;
 
+        virtual void set_breakpoint (const UString &a_func_name,
+                                     const BreakpointsSlot &a_slot,
+                                     const UString &a_condition = "",
+                                     gint a_ignore_count = 0,
+                                     const UString &a_cookie = "") = 0;
+
     virtual void set_breakpoint (const Address &a_address,
                                  const UString &a_condition = "",
                                  gint a_ignore_count = 0,
                                  const UString &a_cookie = "") = 0;
 
-    virtual void enable_breakpoint (gint a_break_num,
+    virtual void enable_breakpoint (const string& a_break_num,
                                     const BreakpointsSlot &a_slot,
                                     const UString &a_cookie="") = 0;
 
-    virtual void enable_breakpoint (gint a_break_num,
+    virtual void enable_breakpoint (const string& a_break_num,
                                     const UString &a_cookie="") = 0;
 
-    virtual void disable_breakpoint (gint a_break_num,
+    virtual void disable_breakpoint (const string& a_break_num,
                                      const UString &a_cookie="") = 0;
 
     virtual void set_breakpoint_ignore_count
-                                        (gint a_break_num,
+                                        (const string& a_break_num,
                                          gint a_ignore_count,
                                          const UString &a_cookie = "") = 0;
 
-    virtual void set_breakpoint_condition (gint a_break_num,
+    virtual void set_breakpoint_condition (const string& a_break_num,
                                            const UString &a_condition,
                                            const UString &a_cookie = "") = 0;
 
-    virtual void enable_countpoint (gint a_break_num,
+    virtual void enable_countpoint (const string& a_break_num,
                                     bool a_flag,
                                     const UString &a_cookie ="") = 0;
 
-    virtual bool is_countpoint (gint a_break_num) const = 0;
+    virtual bool is_countpoint (const string &a_break_num) const = 0;
 
     virtual bool is_countpoint (const Breakpoint &a_breakpoint) const = 0;
 
@@ -1405,9 +1500,9 @@ public:
 
     virtual void list_breakpoints (const UString &a_cookie="") = 0;
 
-    virtual const map<int, Breakpoint>& get_cached_breakpoints () = 0;
+    virtual const map<string, Breakpoint>& get_cached_breakpoints () = 0;
 
-    virtual bool get_breakpoint_from_cache (int a_num,
+    virtual bool get_breakpoint_from_cache (const string &a_num,
                                             IDebugger::Breakpoint &a_bp)
         const = 0;
 
@@ -1417,7 +1512,7 @@ public:
     virtual void choose_function_overloads (const vector<int> &a_numbers,
                                             const UString &a_cookie="") = 0;
 
-    virtual void delete_breakpoint (gint a_break_num,
+    virtual void delete_breakpoint (const string &a_break_num,
                                     const UString &a_cookie="") = 0;
 
     virtual void list_threads (const UString &a_cookie="") = 0;
@@ -1448,6 +1543,9 @@ public:
                                         const FrameArgsSlot &a_slot,
                                         const UString &a_cookie) = 0;
 
+    virtual void list_local_variables (const ConstVariableListSlot &a_slot,
+                                       const UString &a_cookie="") = 0;
+
     virtual void list_local_variables (const UString &a_cookie="") = 0;
 
     virtual void list_global_variables (const UString &a_cookie="") = 0;
