@@ -65,6 +65,7 @@ static gchar *gv_remote = 0;
 static gchar *gv_solib_prefix = 0;
 static gchar *gv_gdb_binary_filepath = 0;
 static gchar *gv_core_path = 0;
+static bool gv_just_load = false;
 
 static GOptionEntry entries[] =
 {
@@ -179,13 +180,22 @@ static GOptionEntry entries[] =
         _("Set the path of the GDB binary to use to debug the inferior"),
         "</path/to/gdb>"
     },
+    {
+        "just-load",
+        0,
+        0,
+        G_OPTION_ARG_NONE,
+        &gv_just_load,
+        _("Do not set a breakpoint in 'main' and do not run the inferior either"),
+        0
+    },
     { 
         "version",
         0,
         0,
         G_OPTION_ARG_NONE,
         &gv_show_version,
-        _("Show the version number of nemiver"),
+        _("Show the version number of Nemiver"),
         0
     },
     {0, 0, 0, (GOptionArg) 0, 0, 0, 0}
@@ -353,7 +363,7 @@ parse_command_line (int& a_argc,
                       "Like this:\n")
                  << "nemiver --remote=" << gv_remote
                  << " <binary-copy>\n\n";
-            cerr << _("Otherwise, find below the full set of nemiver options.\n");
+            cerr << _("Otherwise, find below the full set of Nemiver options.\n");
             GCharSafePtr help_message;
             help_message.reset (g_option_context_get_help (context.get (),
                                                            true, 0));
@@ -372,7 +382,7 @@ parse_command_line (int& a_argc,
                       "Like this:\n")
                  << "nemiver --load-core=\""
                  << gv_core_path << "\" </path/to/binary>\n\n";
-            cerr << _("Otherwise, find below the full set of nemiver options.\n");
+            cerr << _("Otherwise, find below the full set of Nemiver options.\n");
             GCharSafePtr help_message;
             help_message.reset (g_option_context_get_help (context.get (),
                                                            true, 0));
@@ -649,7 +659,10 @@ process_gui_options (int& a_argc, char** a_argv)
             debug_persp->uses_launch_terminal (gv_use_launch_terminal);
             debug_persp->execute_program (prog_path,
                                           prog_args,
-                                          env);
+                                          env,
+                                          /*a_cwd=*/".",
+                                          /*a_clone_opened_files=*/false,
+                                          /*a_break_in_main_run=*/!gv_just_load);
         }
     } else {
         cerr << "Could not find the debugger perspective plugin\n";
