@@ -54,7 +54,7 @@ struct DBGPerspectiveTwoPaneLayout::Priv {
     SafePtr<Gtk::Paned> horizontal_paned;
     SafePtr<Gtk::Notebook> horizontal_statuses_notebook;
     SafePtr<Gtk::Notebook> vertical_statuses_notebook;
-    map<int, Gtk::Widget&> views;
+    map<int, Gtk::Widget*> views;
     IDBGPerspective &dbg_perspective;
 
     Priv (IDBGPerspective &a_dbg_perspective) :
@@ -196,7 +196,7 @@ DBGPerspectiveTwoPaneLayout::activate_view (int a_view)
     THROW_IF_FAIL (m_priv->views.count (a_view));
 
     Gtk::Notebook &status_notebook = m_priv->statuses_notebook (a_view);
-    int page_num = status_notebook.page_num (m_priv->views.at (a_view));
+    int page_num = status_notebook.page_num (*m_priv->views.at (a_view));
     THROW_IF_FAIL (page_num >= 0);
     status_notebook.set_current_page (page_num);
 }
@@ -231,7 +231,7 @@ DBGPerspectiveTwoPaneLayout::append_view (Gtk::Widget &a_widget,
         return;
     }
 
-    m_priv->views.insert (std::make_pair<int, Gtk::Widget&> (a_index, a_widget));
+    m_priv->views[a_index] = &a_widget;
     a_widget.show_all ();
     Gtk::Notebook &statuses_notebook = m_priv->statuses_notebook (a_index);
     int page_num = statuses_notebook.append_page (a_widget, a_title);
@@ -246,7 +246,8 @@ DBGPerspectiveTwoPaneLayout::remove_view (int a_index)
         return;
     }
 
-    m_priv->statuses_notebook (a_index).remove_page (m_priv->views.at (a_index));
+    m_priv->statuses_notebook (a_index).remove_page
+        (*m_priv->views.at (a_index));
     m_priv->views.erase (a_index);
 }
 
