@@ -199,8 +199,16 @@ public:
 
 };//end FindTextDialog
 
-FindTextDialog::FindTextDialog (const UString &a_root_path) :
-    Dialog (a_root_path, "findtextdialog.ui", "findtextdialog")
+/// Constructor of the FindTextDialog type.
+///
+/// \param a_parent the parent window of the dialog.
+///
+/// \param a_root_path the path to the root directory of the
+/// ressources of the dialog.
+FindTextDialog::FindTextDialog (Gtk::Window &a_parent,
+                                const UString &a_root_path) :
+    Dialog (a_root_path, "findtextdialog.ui",
+            "findtextdialog", a_parent)
 {
     m_priv.reset (new Priv (widget (), gtkbuilder ()));
     THROW_IF_FAIL (m_priv);
