@@ -90,7 +90,7 @@ struct ThreadList::Priv {
                                      bool /*a_has_frame*/,
                                      const IDebugger::Frame &/*a_frame*/,
                                      int a_thread_id,
-                                     int /*bp_num*/,
+                                     const string &/*bp_num*/,
                                      const UString &/*a_cookie*/)
     {
         LOG_FUNCTION_SCOPE_NORMAL_DD;
