@@ -24,21 +24,23 @@
  */
 #include "config.h"
 #include "nmv-terminal.h"
-#if !(defined(__FreeBSD__) || defined(__OpenBSD__))
+#if defined(HAVE_PTY_H)
 # include <pty.h>
-#else
+#elif defined (HAVE_LIBUTIL_H)
 # include <sys/types.h>
 # include <sys/ioctl.h>
 # include <termios.h>
-#if defined(__FreeBSD__)
 # include <libutil.h>
-#else
+#elif defined(HAVE_UTIL_H)
 # include <util.h>
 #endif
-#endif
 #include <unistd.h>
 #include <iostream>
+#if defined(HAVE_TR1_TUPLE)
 #include <tr1/tuple>
+#elif defined(HAVE_BOOST_TR1_TUPLE_HPP)
+#include <boost/tr1/tuple.hpp>
+#endif
 #include <gtkmm/bin.h>
 #include <gtkmm/main.h>
 #include <gtkmm/window.h>
@@ -46,6 +48,7 @@
 #include <gtkmm/menu.h>
 #include <gtkmm/builder.h>
 #include <gtkmm/uimanager.h>
+#include <pangomm/fontdescription.h>
 #include <vte/vte.h>
 #include <glib/gi18n.h>
 #include "common/nmv-exception.h"
@@ -70,7 +73,7 @@ on_button_press_signal (GtkWidget*,
         return false;
     }
 
-    NEMIVER_TRY
+    NEMIVER_TRY;
 
     THROW_IF_FAIL (a_tuple);
     VteTerminal*& vte = std::tr1::get<0> (*a_tuple);
@@ -91,7 +94,7 @@ on_button_press_signal (GtkWidget*,
             (vte_terminal_get_has_selection (vte));
     menu->popup (a_event->button, a_event->time);
 
-    NEMIVER_CATCH
+    NEMIVER_CATCH;
     return true;
 }
 
@@ -133,12 +136,19 @@ struct Terminal::Priv {
         vte = VTE_TERMINAL (w);
         THROW_IF_FAIL (vte);
 
-        // Mandatory for vte 0.14	
+        // Mandatory for vte >= 0.14
+#ifdef HAS_VTE_2_91
+        Pango::FontDescription font_desc ("monospace");
+        vte_terminal_set_font (vte, font_desc.gobj());
+#else // HAS_VTE_2_90
         vte_terminal_set_font_from_string (vte, "monospace");
+#endif
 
         vte_terminal_set_scroll_on_output (vte, TRUE);
         vte_terminal_set_scrollback_lines (vte, 1000);
+#ifdef HAS_VTE_2_90
         vte_terminal_set_emulation (vte, "xterm");
+#endif
 
         widget = Glib::wrap (w);
         THROW_IF_FAIL (widget);
@@ -264,7 +274,17 @@ struct Terminal::Priv {
         THROW_IF_FAIL (slave_pty);
         THROW_IF_FAIL (master_pty);
 
-        vte_terminal_set_pty (vte, master_pty);
+#ifdef HAS_VTE_2_91
+        GError *err = 0;
+        VtePty *p = vte_pty_new_foreign_sync (master_pty, 0, &err);
+        GErrorSafePtr error (err);
+        SafePtr<VtePty, RefGObjectNative, UnrefGObjectNative> pty (p);
+        THROW_IF_FAIL2 (!error, error->message);
+
+        vte_terminal_set_pty (vte, pty.get());
+#else //HAS_VTE_2_90
+      vte_terminal_set_pty (vte, master_pty);
+#endif
         return true;
     }
 };//end Terminal::Priv
@@ -338,4 +358,3 @@ Terminal::feed (const UString &a_text)
 
 
 NEMIVER_END_NAMESPACE(nemiver)
-
